% Following is the MATLAB script for evaluation of drop velocities for eccentric drop configuration. 
% This MATLAB script generates a plot which shows the variation of droplet
% velocity with the parameter \beta
clear all; clc;
hold on; hold all; box on;

Beta = linspace(0,0.9,50);

N1 = 15; N2 = 1000;
g = 10; rho1 = 1000; mu1 = 1e-3;
rho2b = 2; rho3b = 1.5;
lambda2 = 0.1; lambda3 = 5;
R1 = 2e-3; R = 0.2; R0 = 5;
k = 5; alpha = 1; d = 1;
factor = 1;
e = 0.78;
xi1 = acosh((e^2 - R^2 + 1)/(2*e));
xi2 = acosh((- e^2 - R^2 + 1)/(2*e*R));
c = R*sinh(xi2);

for i = 1:length(Beta)
    beta = Beta(i);
omega2 = beta*k/(1-beta);
U0 = 2*g*R1^2*rho1*(rho2b-1)/(9*mu1);
S = 4*pi*g*R1^2*rho1/(3*mu1*U0);
Gr1 = S*((rho2b-1)*(1-R^3)+R^3*(rho3b-1));
Gr2 = S*R^3*(rho3b-rho2b);

A = zeros(11*N1);
B1 = zeros(11*N1,1);
B2 = zeros(11*N1,1);
B3 = zeros(11*N1,1);
Ro = evaluating_R(xi1,N1,N2);
Ri = evaluating_R(xi2,N1,N2);
Rc = evaluating_Rc(xi2,N1,N2);

for  n = 1:N1
    
    
    A(11*(n-1)+1,11*(n-1)+1) = exp((n-1/2)*xi1);
    A(11*(n-1)+1,11*(n-1)+2) = exp((n+3/2)*xi1);
    
    A(11*(n-1)+2,11*(n-1)+4) = exp((n-1/2)*xi1);
    A(11*(n-1)+2,11*(n-1)+5) = exp((n+3/2)*xi1);
    A(11*(n-1)+2,11*(n-1)+6) = exp(-(n-1/2)*xi1);
    A(11*(n-1)+2,11*(n-1)+7) = exp(-(n+3/2)*xi1);
    
    A(11*(n-1)+3,11*(n-1)+1) = -(n-1/2)*exp((n-1/2)*xi1);
    A(11*(n-1)+3,11*(n-1)+2) = -(n+3/2)*exp((n+3/2)*xi1);
    A(11*(n-1)+3,11*(n-1)+4) = (n-1/2)*exp((n-1/2)*xi1);
    A(11*(n-1)+3,11*(n-1)+5) = (n+3/2)*exp((n+3/2)*xi1);
    A(11*(n-1)+3,11*(n-1)+6) = (-n+1/2)*exp(-(n-1/2)*xi1);
    A(11*(n-1)+3,11*(n-1)+7) = (-n-3/2)*exp(-(n+3/2)*xi1);
    
    
    
    A(11*(n-1)+4,11*(n-1)+1) = (n-1/2)*exp((n-1/2)*xi1);
    A(11*(n-1)+4,11*(n-1)+2) = (n+3/2)*exp((n+3/2)*xi1);
    A(11*(n-1)+4,11*(n-1)+3) = -1/c;
    
    A(11*(n-1)+5,11*(n-1)+1) = (n-1/2)^2*exp((n-1/2)*xi1);
    A(11*(n-1)+5,11*(n-1)+2) = (n+3/2)^2*exp((n+3/2)*xi1);
    A(11*(n-1)+5,11*(n-1)+4) = -lambda2*(n-1/2)^2*exp((n-1/2)*xi1);
    A(11*(n-1)+5,11*(n-1)+5) = -lambda2*(n+3/2)^2*exp((n+3/2)*xi1);
    A(11*(n-1)+5,11*(n-1)+6) = -lambda2*(-n+1/2)^2*exp(-(n-1/2)*xi1);
    A(11*(n-1)+5,11*(n-1)+7) = -lambda2*(-n-3/2)^2*exp(-(n+3/2)*xi1);
    
    for k = 1:N1
        A(11*(n-1)+5,11*(k-1)+3) = (1/2)*omega2*n*(n+1)*(2*n+1)*Ro(n,k);
        
    end
    
    A(11*(n-1)+6,11*(n-1)+8) = exp(-(n-1/2)*xi2);
    A(11*(n-1)+6,11*(n-1)+9) = exp(-(n+3/2)*xi2);
    
    A(11*(n-1)+7,11*(n-1)+4) = exp((n-1/2)*xi2);
    A(11*(n-1)+7,11*(n-1)+5) = exp((n+3/2)*xi2);
    A(11*(n-1)+7,11*(n-1)+6) = exp(-(n-1/2)*xi2);
    A(11*(n-1)+7,11*(n-1)+7) = exp(-(n+3/2)*xi2);
    
    
    A(11*(n-1)+8,11*(n-1)+4) = -(n-1/2)*exp((n-1/2)*xi2);
    A(11*(n-1)+8,11*(n-1)+5) = -(n+3/2)*exp((n+3/2)*xi2);
    A(11*(n-1)+8,11*(n-1)+6) = -(-n+1/2)*exp(-(n-1/2)*xi2);
    A(11*(n-1)+8,11*(n-1)+7) = -(-n-3/2)*exp(-(n+3/2)*xi2);
    A(11*(n-1)+8,11*(n-1)+8) = (-n+1/2)*exp(-(n-1/2)*xi2);
    A(11*(n-1)+8,11*(n-1)+9) = (-n-3/2)*exp(-(n+3/2)*xi2);
    
    A(11*(n-1)+9,11*(n-1)+8) = (-n+1/2)*exp(-(n-1/2)*xi2)/d;
    A(11*(n-1)+9,11*(n-1)+9) = (-n-3/2)*exp(-(n+3/2)*xi2)/d;
    A(11*(n-1)+9,11*(n-1)+10) = -1/c;
    
    A(11*(n-1)+10,11*(n-1)+8) = (1/2)*exp(-(n-1/2)*xi2)*sinh(xi2)/d;
    A(11*(n-1)+10,11*(n-1)+9) = (1/2)*exp(-(n+3/2)*xi2)*sinh(xi2)/d;
    A(11*(n-1)+10,11*(n-1)+11) = -1/c;
    
    A(11*(n-1)+11,11*(n-1)+4) = lambda2*(n-1/2)^2*exp((n-1/2)*xi2);
    A(11*(n-1)+11,11*(n-1)+5) = lambda2*(n+3/2)^2*exp((n+3/2)*xi2);
    A(11*(n-1)+11,11*(n-1)+6) = lambda2*(-n+1/2)^2*exp(-(n-1/2)*xi2);
    A(11*(n-1)+11,11*(n-1)+7) = lambda2*(-n-3/2)^2*exp(-(n+3/2)*xi2);
    A(11*(n-1)+11,11*(n-1)+8) = -lambda3*(-n+1/2)^2*exp(-(n-1/2)*xi2)+(1/4*(lambda2-lambda3))*(2*n+3)*(2*n-1)*exp(-(n-1/2)*xi2);
    A(11*(n-1)+11,11*(n-1)+9) = -lambda3*(-n-3/2)^2*exp(-(n+3/2)*xi2)+(1/4*(lambda2-lambda3))*(2*n+3)*(2*n-1)*exp(-(n+3/2)*xi2);
    
    for k = 1:N1
        A(11*(n-1)+11,11*(k-1)+10) = (1/2)*alpha*omega2*n*(n+1)*(2*n+1)*Ri(n,k);
        A(11*(n-1)+11,11*(k-1)+11) = (1/2)*alpha*omega2*n*(n+1)*(2*n+1)*Rc(n,k);
        
    end
    
    
    B1(11*(n-1)+1,1) = (2/3)*n*sqrt(2)*(-(3/2)*R0^2*(n+3/2)*exp(-xi1*n+(1/2)*xi1)+(3/2)*exp(-xi1*n-(3/2)*xi1)*(n-1/2)*R0^2)*(n+1)*c^2/(R0^2*(2*n-1)*(2*n+3));
    B2(11*(n-1)+1,1) = 0;
    B3(11*(n-1)+1,1) = -(2/3)*n*sqrt(2)*((c^2*n^2+5*c^2*n+(3/2)*R0^2+6*c^2)*(n-1/2)*exp(-xi1*n-(3/2)*xi1)-(n+3/2)*(c^2*n^2-3*c^2*n+(3/2)*R0^2+2*c^2)*exp(-xi1*n+(1/2)*xi1))*(n+1)*c^2/(R0^2*(2*n-1)*(2*n+3));
    
    B1(11*(n-1)+3,1) = (1/6)*n*sqrt(2)*(-(3/2)*exp(-xi1*n+(1/2)*xi1)*R0^2+(3/2)*exp(-xi1*n-(3/2)*xi1)*R0^2)*(n+1)*c^2/R0^2;
    B2(11*(n-1)+3,1) = 0;
    B3(11*(n-1)+3,1) = -(1/6)*n*sqrt(2)*(((n^2+5*n+6)*c^2+(3/2)*R0^2)*exp(-xi1*n-(3/2)*xi1)-((n^2-3*n+2)*c^2+(3/2)*R0^2)*exp(-xi1*n+(1/2)*xi1))*(n+1)*c^2/R0^2;
    
    B1(11*(n-1)+4,1) = -(1/6)*n*sqrt(2)*(-(3/2)*exp(-xi1*n+(1/2)*xi1)*R0^2+(3/2)*exp(-xi1*n-(3/2)*xi1)*R0^2)*(n+1)*c^2/R0^2;
    B2(11*(n-1)+4,1) = 0;
    B3(11*(n-1)+4,1) = (1/6)*n*sqrt(2)*(((n^2+5*n+6)*c^2+(3/2)*R0^2)*exp(-xi1*n-(3/2)*xi1)-((n^2-3*n+2)*c^2+(3/2)*R0^2)*exp(-xi1*n+(1/2)*xi1))*(n+1)*c^2/R0^2;
    
    B1(11*(n-1)+5,1) = (1/6)*n*(-(3/2)*R0^2*(n-1/2)*exp(-xi1*n+(1/2)*xi1)+(3/2*(n+3/2))*exp(-xi1*n-(3/2)*xi1)*R0^2)*sqrt(2)*(n+1)*c^2/R0^2;
    B2(11*(n-1)+5,1) = 0;
    B3(11*(n-1)+5,1) = -(1/6)*n*sqrt(2)*((n+3/2)*(c^2*n^2+5*c^2*n+(3/2)*R0^2+6*c^2)*exp(-xi1*n-(3/2)*xi1)-(c^2*n^2-3*c^2*n+(3/2)*R0^2+2*c^2)*exp(-xi1*n+(1/2)*xi1)*(n-1/2))*(n+1)*c^2/R0^2;
    
    B1(11*(n-1)+6,1) = (1/2)*c^2*n*(n+1)*sqrt(2)*(2*exp(-(1/2*(2*n-1))*xi2)*n+3*exp(-(1/2*(2*n-1))*xi2)-2*exp(-(1/2*(2*n+3))*xi2)*n+exp(-(1/2*(2*n+3))*xi2))/((2*n-1)*(2*n+3));
    B2(11*(n-1)+6,1) = -(1/2)*c^2*n*(n+1)*sqrt(2)*(2*exp(-(1/2*(2*n-1))*xi2)*n+3*exp(-(1/2*(2*n-1))*xi2)-2*exp(-(1/2*(2*n+3))*xi2)*n+exp(-(1/2*(2*n+3))*xi2))/((2*n-1)*(2*n+3));
    B3(11*(n-1)+6,1) = 0;
    
    B1(11*(n-1)+7,1) = (1/2)*c^2*n*(n+1)*sqrt(2)*(2*exp(-(1/2*(2*n-1))*xi2)*n+3*exp(-(1/2*(2*n-1))*xi2)-2*exp(-(1/2*(2*n+3))*xi2)*n+exp(-(1/2*(2*n+3))*xi2))/((2*n-1)*(2*n+3));
    B2(11*(n-1)+7,1) = -(1/2)*c^2*n*(n+1)*sqrt(2)*(2*exp(-(1/2*(2*n-1))*xi2)*n+3*exp(-(1/2*(2*n-1))*xi2)-2*exp(-(1/2*(2*n+3))*xi2)*n+exp(-(1/2*(2*n+3))*xi2))/((2*n-1)*(2*n+3));
    B3(11*(n-1)+7,1) = 0;
    
    B1(11*(n-1)+11,1) = (1/4*(lambda2-lambda3))*c^2*n*(n+1)*(2*n+1)*(exp(-(1/2*(2*n-1))*xi2)-exp(-(1/2*(2*n+3))*xi2))*sqrt(2);
    B2(11*(n-1)+11,1) = -(1/4*(lambda2-lambda3))*c^2*n*(n+1)*(2*n+1)*(exp(-(1/2*(2*n-1))*xi2)-exp(-(1/2*(2*n+3))*xi2))*sqrt(2);
    B3(11*(n-1)+11,1) = 0;
    
end


B3 = factor*B3;

X1 = A\B1;
X2 = A\B2;
X3 = A\B3;

Lo1 = 0; Lo2 = 0; Lo3 = 0;
Li1 = 0; Li2 = 0; Li3 = 0;

for n = 1:N1
    
    Lo1 = Lo1 + 4*sqrt(2)*pi/c*(X1(11*(n-1)+1) + X1(11*(n-1)+2));
    Lo2 = Lo2 + 4*sqrt(2)*pi/c*(X2(11*(n-1)+1) + X2(11*(n-1)+2));
    Lo3 = Lo3 + 4*sqrt(2)*pi/c*(X3(11*(n-1)+1) + X3(11*(n-1)+2));
    Li1 = Li1 + 4*sqrt(2)*pi/c*(X1(11*(n-1)+4) + X1(11*(n-1)+5));
    Li2 = Li2 + 4*sqrt(2)*pi/c*(X2(11*(n-1)+4) + X2(11*(n-1)+5));
    Li3 = Li3 + 4*sqrt(2)*pi/c*(X3(11*(n-1)+4) + X3(11*(n-1)+5));
    
end

AA = [Lo1 Lo2; Li1 Li2];
BB = [Gr1*(1-factor)-Lo3; Gr2*(1-factor)-Li3];
clc
U = AA\BB;
U2(i) = U(1);
U3(i) = U(2);

end


plot(Beta,U2/U2(1))
xlabel('$\beta$'); ylabel('$U_{2}/U_(2,k=0)$');
